LiquidRoundedRectangle class

Represents a rounded rectangle shape that can be used by a LiquidGlass widget.

Works like a RoundedRectangleBorder.

Inheritance

Constructors

LiquidRoundedRectangle({required double borderRadius, BorderSide side = BorderSide.none})
Creates a new LiquidRoundedRectangle with the given borderRadius.
const

Properties

borderRadius → double
The radius of the rounded rectangle.
final
dimensions → EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setterinherited
effectiveRadius → double
The effective corner radius passed to the shader for this shape.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isSuperellipse → bool
Returns whether this shape is a superellipse (squircle) rather than a standard rounded rectangle.
no setterinherited
preferPaintInterior → bool
Reports whether paintInterior is implemented.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → BorderSide
The border outline's color and weight.
finalinherited

Methods

add(ShapeBorder other, {bool reversed = false}) → ShapeBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
copyWith({BorderSide? side, double? borderRadius}) → LiquidRoundedRectangle
Returns a copy of this OutlinedBorder that draws its outline with the specified side, if side is non-null.
override
getInnerPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the inner edge of the border.
inherited
getOuterPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the outer edge of the border.
inherited
lerpFrom(ShapeBorder? a, double t) → ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) → ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) → void
Paints the border within the given Rect on the given Canvas.
inherited
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) → ShapeBorder
Creates a copy of this border, scaled by the factor t.
override
toBorderRadius() → BorderRadius
Returns the BorderRadius associated with this shape if it has rounded corners, or null if the shape is inherently non-rectangular (e.g. LiquidOval).
override
toOutlinedBorder() → OutlinedBorder
Returns the equivalent standard Flutter OutlinedBorder representing this shape.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator +(ShapeBorder other) → ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) → bool
The equality operator.
override