interactionScale property

double? interactionScale
final

The scale factor applied when the user presses the widget.

  • 1.0 = no scaling
  • 1.05 (widget default) = 5% grow on press
  • 1.1 = 10% grow on press

When null, each widget uses its own default (typically 1.05).

Implementation

final double? interactionScale;