clearSessionCache static method
Clears the in-session quality cache.
For testing only. Call between tests to prevent cache leakage across test cases.
Implementation
@visibleForTesting
static void clearSessionCache() => _sessionSettledQuality = null;
Clears the in-session quality cache.
For testing only. Call between tests to prevent cache leakage across test cases.
@visibleForTesting
static void clearSessionCache() => _sessionSettledQuality = null;