targetFrameMs property
The target frame duration in milliseconds (e.g. 16 for 60 Hz, 8 for ProMotion / 120 Hz). Thresholds for degradation and upgrade are derived from this value.
Implementation
final int targetFrameMs;
The target frame duration in milliseconds (e.g. 16 for 60 Hz, 8 for ProMotion / 120 Hz). Thresholds for degradation and upgrade are derived from this value.
final int targetFrameMs;