builder property
The builder called on every frame with the current value and velocity.
Implementation
final VelocitySpringWidgetBuilder builder;
The builder called on every frame with the current value and velocity.
final VelocitySpringWidgetBuilder builder;