allowElevation property
Whether to allow elevation effects when in a grouped context.
When false (default), the container won't darken or add rim effects when inside another glass container. This is correct for most containers as they are surfaces, not interactive elements.
Set to true only for special cases where elevation is needed.
Defaults to false.
Implementation
final bool allowElevation;