child property
The widget below this widget in the tree.
This is the content that will be displayed inside the glass container.
Implementation
final Widget? child;
The widget below this widget in the tree.
This is the content that will be displayed inside the glass container.
final Widget? child;