onStepTapped property
Called when the user taps on a step header.
If null, tapping headers has no effect (controlled wizard).
Implementation
final ValueChanged<int>? onStepTapped;
Called when the user taps on a step header.
If null, tapping headers has no effect (controlled wizard).
final ValueChanged<int>? onStepTapped;