content property
Optional expanded content shown when this step is active.
If null, the step header collapses to a label only.
Implementation
final Widget? content;
Optional expanded content shown when this step is active.
If null, the step header collapses to a label only.
final Widget? content;