leading property
Optional custom widget for the step indicator circle.
If null, the default numbered circle or checkmark is shown.
Implementation
final Widget? leading;
Optional custom widget for the step indicator circle.
If null, the default numbered circle or checkmark is shown.
final Widget? leading;