useOwnLayer property
Whether to create its own AdaptiveLiquidGlassLayer.
If false (default), the indicator must be inside a AdaptiveLiquidGlassLayer. If true, creates an independent glass layer with settings.
Implementation
final bool useOwnLayer;
Whether to create its own AdaptiveLiquidGlassLayer.
If false (default), the indicator must be inside a AdaptiveLiquidGlassLayer. If true, creates an independent glass layer with settings.
final bool useOwnLayer;