maxHeight property
Maximum height constraint.
When set, the field will not grow beyond this height and will scroll internally once the content exceeds the available space.
Implementation
final double? maxHeight;
Maximum height constraint.
When set, the field will not grow beyond this height and will scroll internally once the content exceeds the available space.
final double? maxHeight;