glowSpreadRadius property
Extra glow circle spread as a fraction of the layer's shortest side.
If null, the value from GlassThemeData.glowColorsFor is used.
Implementation
final double? glowSpreadRadius;
Extra glow circle spread as a fraction of the layer's shortest side.
If null, the value from GlassThemeData.glowColorsFor is used.
final double? glowSpreadRadius;