settings property

LiquidGlassSettings? settings
final

Glass effect settings for the button.

Controls the visual appearance of the glass effect including thickness, blur radius, color tint, lighting, and more.

If null, settings are inherited from DefaultButtonSettings (set via GlassAppBar.buttonSettings), then from the page-level glass layer, then from the app-level GlassTheme.

Implementation

final LiquidGlassSettings? settings;