width property

double? width
final

Width of the button in logical pixels.

When null, the button will size itself based on parent constraints (e.g. expanding to fill an Expanded widget).

The default GlassButton constructor sets this to 56.0 for icon buttons. The GlassButton.custom constructor defaults to null so the button respects flexible parent layouts.

Implementation

final double? width;