items property
Lightweight item data for icon-based groups.
When non-null, children is ignored and items are rendered internally as lightweight icons with press-dim feedback.
Implementation
final List<GlassGroupItem>? items;
Lightweight item data for icon-based groups.
When non-null, children is ignored and items are rendered internally as lightweight icons with press-dim feedback.
final List<GlassGroupItem>? items;