icon property
The icon widget to display.
Typically a CupertinoIcon or Icon. The parent GlassButtonGroup
wraps this in an IconTheme that sets size and color based on the
current brightness.
Implementation
final Widget icon;
The icon widget to display.
Typically a CupertinoIcon or Icon. The parent GlassButtonGroup
wraps this in an IconTheme that sets size and color based on the
current brightness.
final Widget icon;