menuAlignment property
Controls where the menu expands relative to the trigger button.
Defaults to auto-detection. Set via GlassButtonGroupItem.menu.
Implementation
final GlassMenuAlignment? menuAlignment;
Controls where the menu expands relative to the trigger button.
Defaults to auto-detection. Set via GlassButtonGroupItem.menu.
final GlassMenuAlignment? menuAlignment;