anchorStretch property
Whether to anchor the button in place while stretching toward the finger.
Defaults to true. See GlassButton.anchorStretch.
Implementation
final bool anchorStretch;
Whether to anchor the button in place while stretching toward the finger.
Defaults to true. See GlassButton.anchorStretch.
final bool anchorStretch;