semanticLabel property
The semantic label for screen readers.
Critical for icon buttons which otherwise have no textual content.
Implementation
final String? semanticLabel;
The semantic label for screen readers.
Critical for icon buttons which otherwise have no textual content.
final String? semanticLabel;