continuousSwipeSlop property

double continuousSwipeSlop
final

The movement slop in logical pixels required to arm continuous swipe.

If the pointer is released within this distance of the initial touch-down, the gesture is treated as a tap and the menu remains open without selecting an item.

Defaults to 10.0.

Implementation

final double continuousSwipeSlop;