enableContinuousSwipe property

bool enableContinuousSwipe
final

Whether to enable iOS-style continuous swipe-to-select.

When true, pressing down on the button opens the menu immediately and allows the user to slide to an item and release to activate it in a single continuous gesture without lifting their finger.

Defaults to true.

Implementation

final bool enableContinuousSwipe;