widgets/interactive/liquid_glass_scope library

Classes

GlassBackgroundSource
Marks a widget as the texture capture source for the nearest LiquidGlassScope.
LiquidGlassScope
A scope that provides infrastructure for glass refraction on Skia and Web.