useOwnLayer property

bool useOwnLayer
final

If true, wraps the glass layer in a RepaintBoundary (own compositing layer). This can improve performance when the glass surface moves independently of the rest of the widget tree, at the cost of extra GPU memory. Defaults to true.

Implementation

final bool useOwnLayer;