reduceTransparency property

bool reduceTransparency
final

When true, the glass shader should degrade to a plain frosted surface.

Sourced from MediaQuery.highContrastOf as the closest available Flutter proxy for iOS "Reduce Transparency".

Implementation

final bool reduceTransparency;