phase property
The current adaptation phase (probe → warmup → runtime).
Useful for analytics or development UIs. Widgets should not change their behaviour based on this value.
Implementation
final AdaptivePhase phase;
The current adaptation phase (probe → warmup → runtime).
Useful for analytics or development UIs. Widgets should not change their behaviour based on this value.
final AdaptivePhase phase;