GlassStatusBarStyle enum

Controls how GlassPage styles the system status bar.

Inheritance
Available extensions

Values

none → const GlassStatusBarStyle

Leaves the system status bar style unchanged. Default.

dark → const GlassStatusBarStyle

Dark status bar icons (for use over light backgrounds).

light → const GlassStatusBarStyle

Light status bar icons (for use over dark backgrounds / wallpapers).

auto → const GlassStatusBarStyle

Automatically selects dark or light based on the current MediaQuery platform brightness. Dark mode → light icons; light mode → dark icons.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GlassStatusBarStyle>
A constant List of the values in this enum, in order of their declaration.