topFadeHeight property

double topFadeHeight
final

The height of the top fade zone in logical pixels.

Content within this zone fades from fully transparent (at the top edge) to fully visible. Should cover the safe area + navigation bar height + a buffer zone.

Defaults to 100.0.

Implementation

final double topFadeHeight;