GlassBottomBar class

Inheritance

Constructors

GlassBottomBar({required List<GlassBottomBarTab> tabs, required int selectedIndex, required ValueChanged<int> onTabSelected, Key? key, GlassBottomBarExtraButton? extraButton, double spacing = 8, double horizontalPadding = 20, double verticalPadding = 20, double barHeight = 64, double barBorderRadius = _defaultBarBorderRadius, EdgeInsetsGeometry tabPadding = const EdgeInsets.symmetric(horizontal: 4), double iconLabelSpacing = 4, double blendAmount = 10, LiquidGlassSettings? glassSettings, bool showIndicator = true, Color? indicatorColor, LiquidGlassSettings? indicatorSettings, Color selectedIconColor = Colors.white, Color unselectedIconColor = Colors.white, double iconSize = 24, double labelFontSize = 11, TextStyle? textStyle, Duration glowDuration = const Duration(milliseconds: 300), double glowBlurRadius = 32, double glowSpreadRadius = 8, double glowOpacity = 0.6, GlassQuality? quality, double magnification = 1.0, double innerBlur = 0.0, MaskingQuality maskingQuality = MaskingQuality.high, GlobalKey<State<StatefulWidget>>? backgroundKey, Color? interactionGlowColor, double interactionGlowRadius = 1.5, GlassInteractionBehavior interactionBehavior = GlassInteractionBehavior.full, double pressScale = 1.04})
Creates a glass bottom navigation bar.
const

Properties

backgroundKey GlobalKey<State<StatefulWidget>>?
Optional background key for Skia/Web refraction.
final
barBorderRadius double
final
barHeight double
Height of the tab bar.
final
blendAmount double
Blend amount for glass surfaces.
final
extraButton GlassBottomBarExtraButton?
Optional extra button displayed to the right of the tab bar.
final
glassSettings LiquidGlassSettings?
Glass effect settings for the bottom bar.
final
glowBlurRadius double
Blur radius of the glow effect.
final
glowDuration Duration
Duration of the glow animation when selecting a tab.
final
glowOpacity double
Opacity of the glow effect when a tab is selected.
final
glowSpreadRadius double
Spread radius of the glow effect.
final
hashCode int
The hash code for this object.
no setterinherited
horizontalPadding double
Horizontal padding around the entire bottom bar content.
final
iconLabelSpacing double
Internal spacing of the tab bar.
final
iconSize double
Size of the tab icons.
final
indicatorColor Color?
Color of the subtle indicator shown when not being dragged.
final
indicatorSettings LiquidGlassSettings?
Glass settings for the draggable indicator.
final
innerBlur double
Blur amount in logical pixels applied to content inside the indicator.
final
interactionBehavior GlassInteractionBehavior
Controls which physical interaction effects are active when the user presses the bar.
final
interactionGlowColor Color?
The color of the directional glow effect when interacting with the bar.
final
interactionGlowRadius double
The radius spread of the directional glow effect when interacting with the bar.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelFontSize double
Font size for tab labels.
final
magnification double
Magnification factor for the content inside the selected indicator.
final
maskingQuality MaskingQuality
Quality of the liquid glass masking effect.
final
onTabSelected ValueChanged<int>
Called when a tab is selected.
final
pressScale double
Peak scale factor applied to the bar at maximum press depth.
final
quality GlassQuality?
Rendering quality for the glass effect.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIconColor Color
Color of the icon when a tab is selected.
final
selectedIndex int
Index of the currently selected tab.
final
showIndicator bool
Whether to show the draggable indicator.
final
spacing double
Spacing between the tab bar and extra button.
final
tabPadding EdgeInsetsGeometry
Internal padding of the tab bar.
final
tabs List<GlassBottomBarTab>
List of tabs to display in the bottom bar.
final
textStyle TextStyle?
Text style for tab labels.
final
unselectedIconColor Color
Color of the icon when a tab is not selected.
final
verticalPadding double
Vertical padding above and below the bottom bar content.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<GlassBottomBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited