enabled property
Whether pinning is enabled at all.
When false the shell is inert and every screen renders its bar chrome in-route, exactly as if no shell were installed.
Implementation
final bool enabled;
Whether pinning is enabled at all.
When false the shell is inert and every screen renders its bar chrome in-route, exactly as if no shell were installed.
final bool enabled;