debugPinningSupported property
Overrides the capability gate in tests, where no GPU is available.
Implementation
@visibleForTesting
static bool? debugPinningSupported;
Overrides the capability gate in tests, where no GPU is available.
@visibleForTesting
static bool? debugPinningSupported;