isActive property
bool
get
isActive
Whether pinning is currently active.
False when the shell is disabled or the resolved glass quality can't render the effect, in which case registrants render in-route instead.
Implementation
bool get isActive => widget.enabled && _pinningSupported;