searchFocused property
bool
get
searchFocused
Whether the search text field is currently focused (keyboard visible).
Implementation
bool get searchFocused => _searchFocused;
Whether the search text field is currently focused (keyboard visible).
bool get searchFocused => _searchFocused;