TabBarBottomLayout class

Internal StatefulWidget that owns the bottom-placement rendering engine.

Created by GlassTabBar._buildBottom() when _GlassTabBarPlacement.bottom is active. Not part of the public API.

Inheritance

Constructors

TabBarBottomLayout({required List<GlassBottomBarTab> tabs, required int selectedIndex, required ValueChanged<int> onTabSelected, Key? key, GlassTabBarExtraButton? extraButton, double spacing = 8, double horizontalPadding = 20, double verticalPadding = 20, double barHeight = 64, double barBorderRadius = _kDefaultBorderRadius, EdgeInsetsGeometry tabPadding = const EdgeInsets.symmetric(horizontal: 4), double iconLabelSpacing = 4, bool enableBlend = true, double blendAmount = 10, LiquidGlassSettings? settings, bool showIndicator = true, Color? indicatorColor, LiquidGlassSettings? indicatorSettings, double indicatorPinchStrength = 0.4, Color? selectedIconColor, Color? unselectedIconColor, Color? selectedLabelColor, Color? unselectedLabelColor, TextStyle? selectedLabelStyle, TextStyle? unselectedLabelStyle, double iconSize = 24, double labelFontSize = 11, TextStyle? textStyle, Duration glowDuration = const Duration(milliseconds: 300), double glowBlurRadius = 32, double glowSpreadRadius = 8, double glowOpacity = 0.6, GlassQuality? quality, double magnification = 1.15, double innerBlur = 0.0, MaskingQuality maskingQuality = MaskingQuality.high, GlobalKey<State<StatefulWidget>>? backgroundKey, double? tabWidth, double? indicatorBorderRadius, EdgeInsetsGeometry indicatorExpansion = const EdgeInsets.symmetric(horizontal: 12, vertical: 8), Color? interactionGlowColor, double interactionGlowRadius = 1.5, GlassInteractionBehavior interactionBehavior = GlassInteractionBehavior.full, double pressScale = 1.04, bool platformViewBackdrop = false, bool adaptiveBrightness = false, ValueChanged<Brightness>? onBrightnessChanged, ValueListenable<Brightness>? brightnessOverride})
const

Properties

adaptiveBrightness bool
final
backgroundKey GlobalKey<State<StatefulWidget>>?
final
barBorderRadius double
final
barHeight double
final
blendAmount double
final
brightnessOverride ValueListenable<Brightness>?
final
enableBlend bool
final
extraButton GlassTabBarExtraButton?
final
glowBlurRadius double
final
glowDuration Duration
final
glowOpacity double
final
glowSpreadRadius double
final
hashCode int
The hash code for this object.
no setterinherited
horizontalPadding double
final
iconLabelSpacing double
final
iconSize double
final
indicatorBorderRadius double?
final
indicatorColor Color?
final
indicatorExpansion EdgeInsetsGeometry
final
indicatorPinchStrength double
final
indicatorSettings LiquidGlassSettings?
final
innerBlur double
final
interactionBehavior GlassInteractionBehavior
final
interactionGlowColor Color?
final
interactionGlowRadius double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelFontSize double
final
magnification double
final
maskingQuality MaskingQuality
final
onBrightnessChanged ValueChanged<Brightness>?
final
onTabSelected ValueChanged<int>
final
platformViewBackdrop bool
final
pressScale double
final
quality GlassQuality?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIconColor Color?
final
selectedIndex int
final
selectedLabelColor Color?
final
selectedLabelStyle TextStyle?
final
settings LiquidGlassSettings?
final
showIndicator bool
final
spacing double
final
tabPadding EdgeInsetsGeometry
final
tabs List<GlassBottomBarTab>
final
tabWidth double?
final
textStyle TextStyle?
final
unselectedIconColor Color?
final
unselectedLabelColor Color?
final
unselectedLabelStyle TextStyle?
final
verticalPadding double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TabBarBottomLayout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited