isMenu property
bool
get
isMenu
Whether this button opens a menu rather than firing a tap callback.
Implementation
bool get isMenu => menuItems != null;
Whether this button opens a menu rather than firing a tap callback.
bool get isMenu => menuItems != null;