menuAlignment property
Controls where the menu expands relative to the trigger button.
Defaults to auto-detection (upward for bottom-bar placement). Set via GlassTabBarExtraButton.menu.
Implementation
final GlassMenuAlignment? menuAlignment;
Controls where the menu expands relative to the trigger button.
Defaults to auto-detection (upward for bottom-bar placement). Set via GlassTabBarExtraButton.menu.
final GlassMenuAlignment? menuAlignment;