indicatorShadow property
Optional shadows for the active indicator pill. Passed through to AnimatedGlassIndicator but suppressed while a drag is in progress so the shadow does not interact with the live BackdropFilter blur.
Implementation
final List<BoxShadow>? indicatorShadow;