SpringRetarget class

Describes which spring animation axes need to be retargeted.

Returned by SearchableBottomBarController.checkRetarget.

Annotations

Constructors

SpringRetarget({required bool tabW, required bool searchLeft, required bool searchW})
Creates a retarget descriptor.
const

Properties

any → bool
true when at least one axis needs retargeting.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchLeft → bool
Whether the search pill left edge spring needs retargeting.
final
searchW → bool
Whether the search pill width spring needs retargeting.
final
tabW → bool
Whether the tab pill width spring needs retargeting.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const SpringRetarget
No axes need retargeting.