Default light-mode glass shadow values, matching iOS 26 elevation.
Used by AdaptiveGlass and the internal tab indicator and search pill components. Centralised here to prevent drift between the independent shadow wrappers.
These shadows are inverse-clipped so they only appear outside the glass boundary, preventing the glass from blurring its own shadow.
Usage
// Use the defaults
GlassShadow.defaults
// Scale the defaults
GlassShadow.scaled(1.5) // 50% stronger
// Disable shadows
GlassShadow.scaled(0.0) // empty list
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited