liquid_glass_widgets library
Liquid Glass Implementation according to Apple's Guidelines
Classes
- AdaptiveGlass
- Adaptive glass widget that intelligently chooses between premium and lightweight shaders based on renderer capabilities.
- AdaptiveLiquidGlassLayer
- An adaptive liquid glass layer that provides a glass background with proper fallback handling across all platforms.
- GlassAccessibilityData
- Accessibility state for the liquid glass widget tree.
- GlassAccessibilityScope
- Reads system accessibility preferences and makes them available to all glass widgets below it in the widget tree.
- GlassActionSheetAction
-
An action that can be taken from a
GlassActionSheet. - GlassAppBar
- A glass morphism app bar following Apple's navigation bar design.
- GlassBadge
- A glass morphism badge following iOS 26 liquid glass design.
- GlassBottomBar
- GlassBottomBarExtraButton
- Configuration for the extra button in GlassBottomBar.
- GlassBottomBarTab
- Configuration for a tab in GlassBottomBar.
- GlassButton
- Glass morphism button with scale animation and glow effects.
- GlassButtonGroup
- A container that groups multiple buttons visually.
- GlassCard
- A glass card widget following Apple's card design patterns.
- GlassChip
- A glass morphism chip following Apple's iOS 26 design patterns.
- GlassContainer
- A foundational glass container widget following Apple's liquid glass design.
- GlassDefaults
- Default values for glass visual properties.
- GlassDialog
- A glass morphism alert dialog following Apple's iOS design patterns.
- GlassDialogAction
- Configuration for a dialog action button.
- GlassDivider
- A glass-aesthetic separator for use between glass content sections.
- GlassFormField
- A standard form field wrapper for glass inputs following iOS design patterns.
- GlassGlow
- Represents a layer that can paint a glowing effect below its child.
- GlassGlowColors
- Color palette for glass glow effects.
- GlassIconButton
- A glass morphism icon button following Apple's iOS 26 design patterns.
- GlassListTile
- A glass-aesthetic list tile following iOS 26 grouped row design.
- GlassMenu
- A liquid glass context menu that morphs from its trigger button.
- GlassMenuItem
- A menu item for use within a GlassMenu.
- GlassMotionScope
- Drives the glass specular highlight angle from a stream of radians.
- GlassPanel
- A glass panel widget for larger surface areas following Apple's design.
- GlassPasswordField
- A secure glass text field for password entry.
- GlassPicker
- A glass picker widget following iOS design patterns.
- GlassProgressIndicator
- A glass morphism progress indicator following Apple's iOS 26 Liquid Glass design patterns.
- GlassPullDownButton
- A toolbar button that opens a liquid glass pull-down menu.
- GlassRefractionSource
- Marks a widget as the refraction capture source for the nearest LiquidGlassScope.
- GlassSearchableBottomBar
- A glass bottom navigation bar with a morphing search pill.
- GlassSearchBar
- A glass morphism search bar following Apple's iOS 26 design patterns.
- GlassSearchBarConfig
- Configuration for the morphing search bar in GlassSearchableBottomBar.
- GlassSegmentedControl
- A glass morphism segmented control following Apple's design patterns.
- GlassSheet
- A glass morphism bottom sheet following Apple's iOS 26 design patterns.
- GlassSideBar
- A vertical navigation sidebar following Apple's iOS 26 liquid glass design guidelines.
- GlassSideBarItem
- A list item designed for GlassSideBar.
- GlassSlider
- A glass morphism slider following Apple's iOS 26 design patterns.
- GlassSnackBar
- Alias for GlassToast to match Material Design naming.
- GlassSpring
- Static spring-description factories that mirror motor's named presets.
- GlassStepper
-
A glass-aesthetic numeric stepper matching iOS 26's
UISteppercontrol. - GlassSwitch
- A glass toggle switch with Apple's signature jump animation.
- GlassTab
- Configuration for a tab in GlassTabBar.
- GlassTabBar
- A glass morphism tab bar following Apple's iOS design patterns.
- GlassTextArea
- A multi-line glass text area.
- GlassTextField
- A glass text field widget following Apple's input field design.
- GlassTheme
- Provides glass theme configuration to descendant widgets.
- GlassThemeData
- Theme data for liquid glass widgets.
- GlassThemeVariant
- Theme configuration for a specific brightness (light or dark).
- GlassToast
- A glass morphism toast/snackbar following iOS 26 liquid glass design.
- GlassToastAction
- Action button that can be displayed in a toast.
- GlassToolbar
- A glass morphism toolbar following Apple's iOS 26 design patterns.
- GlassWizard
- A glass-aesthetic multi-step wizard for sequential flows.
- GlassWizardStep
- A single step in a GlassWizard.
- InheritedLiquidGlass
- A custom inherited widget that provides LiquidGlassSettings to descendants.
- JellyClipper
- Clipper that matches the shape and physics of the jelly indicator.
- LightweightLiquidGlass
- A lightweight, high-performance glass effect widget optimized for scrollable lists and universal platform compatibility.
- LiquidGlassBlendGroup
- A widget that groups multiple liquid glass shapes for blending.
- LiquidGlassLayer
-
Represents a layer of multiple
LiquidGlassshapes or LiquidGlassBlendGroups that have shared LiquidGlassSettings and will be rendered together. - LiquidGlassScope
- A scope that provides infrastructure for glass refraction on Skia and Web.
- LiquidGlassSettings
- Represents the settings for a liquid glass effect.
- LiquidGlassWidgets
- Entry point and configuration for the Liquid Glass Widgets library.
- LiquidOval
-
Represents an ellipse shape that can be used by a
LiquidGlasswidget. - LiquidRoundedRectangle
-
Represents a rounded rectangle shape that can be used by a
LiquidGlasswidget. - LiquidRoundedSuperellipse
-
Represents a squircle shape that can be used by a
LiquidGlasswidget. - LiquidShape
-
Represents a shape that can be used by a
LiquidGlasswidget. - OffsetSpringBuilder
-
Like SpringBuilder but for Offset values.
Equivalent to motor's
MotionBuilder<Offset>withOffsetMotionConverter. - OffsetSpringController
- A controller that drives an Offset value using two independent SingleSpringControllers (one per axis).
- SingleSpringController
-
A lightweight controller that drives a single double value using
SpringSimulation. Equivalent to motor's
SingleMotionController. - SpringBuilder
- Animates a double value to new targets using a spring, calling builder on every frame.
- VelocitySpringBuilder
-
Like SpringBuilder but also provides the current spring
velocityto the builder. Equivalent to motor'sVelocityMotionBuilder/SingleVelocityMotionBuilder.
Enums
- BadgePosition
- Position of the badge relative to the child widget.
- GlassActionSheetStyle
- Style of action sheet action.
- GlassButtonStyle
- Visual style of a glass button.
- GlassIconButtonShape
- Shape options for GlassIconButton.
- GlassQuality
- Rendering quality for glass effects.
- GlassSpecularSharpness
- Specular highlight sharpness for liquid glass surfaces.
- GlassToastPosition
- Position where the toast should appear on screen.
- GlassToastType
- Visual style and semantic meaning of the toast.
- MaskingQuality
- A glass morphism bottom navigation bar following Apple's design patterns.
Mixins
-
GlassIndicatorTapMixin<
T extends StatefulWidget> - Provides the DX1 deferred-tap logic for glass indicator widgets.
Extensions
- GlassQualityExtension on GlassQuality
- Extension to convert GlassQuality to the underlying rendering method.
Properties
- debugPaintLiquidGlassGeometry ↔ bool
-
Whether to paint the liquid glass geometry texture for debugging purposes.
getter/setter pair
Functions
-
showGlassActionSheet<
T> ({required BuildContext context, String? title, String? message, required List< GlassActionSheetAction> actions, String cancelLabel = 'Cancel', bool showCancelButton = true, bool barrierDismissible = true, LiquidGlassSettings? settings, GlassQuality? quality}) → Future<T?> - A glass morphism action sheet following iOS 26 liquid glass design.
Typedefs
- LiquidGlassBackground = GlassRefractionSource
- Deprecated: use GlassRefractionSource instead.
- OffsetSpringWidgetBuilder = Widget Function(BuildContext context, Offset value, Widget? child)
- SpringWidgetBuilder = Widget Function(BuildContext context, double value, Widget? child)
- VelocitySpringWidgetBuilder = Widget Function(BuildContext context, double value, double velocity, Widget? child)