stretch property
The factor to multiply the drag offset by to determine the stretch amount in pixels.
0.0= no drag-following (keeps press-scale effect)0.5(widget default) = balanced natural stretch1.0= matches drag offset exactly (usually too much)
When null, each widget uses its own default (typically 0.5).
Implementation
final double? stretch;