OffsetSpringController class
A controller that drives an Offset value using two independent SingleSpringControllers (one per axis).
Implements Listenable; listeners fire whenever either axis ticks.
- Inheritance
-
- Object
- ChangeNotifier
- OffsetSpringController
Constructors
- OffsetSpringController({required TickerProvider vsync, required SpringDescription spring, Offset initialValue = Offset.zero})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spring ← SpringDescription
-
Change the spring for both axes, redirecting any running simulation.
no getter
- value ↔ Offset
-
Current animated offset.
getter/setter pair
- velocity → Offset
-
Current spring velocity as an Offset.
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
Offset target) → void -
Animate toward
target, preserving current velocity. -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited