VelocitySpringBuilder class
Like SpringBuilder but also provides the current spring velocity to
the builder. Equivalent to motor's VelocityMotionBuilder /
SingleVelocityMotionBuilder.
springWhenActive is used while the user is interacting (dragging). springWhenReleased is used after the user lifts their finger. Switching between them mid-animation redirects the simulation smoothly.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VelocitySpringBuilder
Constructors
- VelocitySpringBuilder({required double value, required SpringDescription springWhenActive, required SpringDescription springWhenReleased, required VelocitySpringWidgetBuilder builder, bool active = true, Widget? child, Key? key})
-
const
Properties
- active → bool
-
Whether the user is currently dragging (selects springWhenActive).
final
- builder → VelocitySpringWidgetBuilder
-
final
- child → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- springWhenActive → SpringDescription
-
Spring used while active is true (following a pointer).
final
- springWhenReleased → SpringDescription
-
Spring used while active is false (settling to rest).
final
- value → double
-
Current target value.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VelocitySpringBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited