GlassWizard class
A glass-aesthetic multi-step wizard for sequential flows.
GlassWizard presents a vertical list of sequential steps, each with an indicator circle, title, optional subtitle, and expandable content.
Note: This widget is a glass-themed multi-step flow component. For the iOS 26 equivalent of
UIStepper(the−/+numeric incrementer), use GlassStepper instead.
GlassWizard(
currentStep: _step,
onStepTapped: (step) => setState(() => _step = step),
steps: [
GlassWizardStep(
title: Text('Account'),
subtitle: Text('Enter your credentials'),
content: Column(
children: [
GlassTextField(label: 'Email'),
GlassButton(
icon: Icon(CupertinoIcons.arrow_right),
label: 'Continue',
onTap: () => setState(() => _step = 1),
),
],
),
),
GlassWizardStep(title: Text('Profile')),
GlassWizardStep(title: Text('Done'), isCompleted: true),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GlassWizard
Constructors
-
GlassWizard({Key? key, required List<
GlassWizardStep> steps, int currentStep = 0, ValueChanged<int> ? onStepTapped, ScrollPhysics? physics, double indicatorSize = 28.0, Color? activeColor, Color? completedColor, Color? inactiveColor, LiquidGlassSettings? settings, GlassQuality? quality, EdgeInsetsGeometry padding = const EdgeInsets.all(16)}) -
Creates a glass wizard with the given steps.
const
Properties
- activeColor → Color?
-
Colour of the active step indicator.
final
- completedColor → Color?
-
Colour of completed step indicators.
final
- currentStep → int
-
Index of the step that is currently active (expanded).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveColor → Color?
-
Colour of inactive step indicators.
final
- indicatorSize → double
-
Diameter of each step indicator circle in logical pixels.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onStepTapped
→ ValueChanged<
int> ? -
Called when the user taps on a step header.
final
- padding → EdgeInsetsGeometry
-
Padding inside the glass container.
final
- physics → ScrollPhysics?
-
Scroll physics for the wizard.
final
- quality → GlassQuality?
-
Rendering quality for the glass effect.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → LiquidGlassSettings?
-
Glass effect settings for the outer container.
final
-
steps
→ List<
GlassWizardStep> -
The steps of the wizard.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited