ProgressiveBlurDirection enum
The edge a ProgressiveBlur is strongest at; it eases to perfectly sharp at the opposite edge. Named after the direction the blur travels — e.g. topToBottom is heavy at the top and dissolves downward (the classic app-bar / status-bar look), bottomToTop is heavy at the bottom (e.g. a bottom bar or a fade above a docked toolbar).
Values
- topToBottom → const ProgressiveBlurDirection
-
Strong at the top edge, sharp at the bottom.
- bottomToTop → const ProgressiveBlurDirection
-
Strong at the bottom edge, sharp at the top.
- leftToRight → const ProgressiveBlurDirection
-
Strong at the left edge, sharp at the right.
- rightToLeft → const ProgressiveBlurDirection
-
Strong at the right edge, sharp at the left.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProgressiveBlurDirection> - A constant List of the values in this enum, in order of their declaration.