ambientBaseLight property
Opacity of the ambient base light when the button is pressed.
iOS 26 buttons maintain a subtle overall surface brightness when active, in addition to the directional glow that follows the finger. This prevents the button from going dark when the finger drags the directional highlight off-edge.
- 0.0: No ambient base light (button goes dark off-edge)
- 0.08 (default): Subtle surface luminosity matching iOS 26
- 0.15: Noticeably brighter surface
Set to 0.0 to disable.
Implementation
final double ambientBaseLight;