excludeFromSemantics property
Whether to exclude this button from the semantics tree.
Useful when the button is used as a purely visual container for other interactive widgets (e.g., in GlassButtonGroup.icons).
Implementation
final bool excludeFromSemantics;