deleteSemanticLabel property
Screen reader label of the delete button.
The delete button is always its own button node, so it can be reached apart from the chip; this names it. Defaults to "Remove" followed by semanticLabel (or label), e.g. "Remove Flutter".
Implementation
final String? deleteSemanticLabel;