GlassContentAwareSubscription class

A live registration of a glass control with a GlassContentAwareScope.

Returned by GlassContentAwareScopeState.register. Holds the control's hysteresis state; cancel detaches the control from the scope.

Properties

brightness → Brightness
The control's current content-aware verdict.
no setter
gridColumns → int
Number of horizontal voting cells for this control.
final
gridRows → int
Number of vertical voting cells for this control.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Detaches the control from the scope. Safe to call more than once.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited