widgets/surfaces/glass_bottom_bar library
Classes
- GlassBottomBar
- GlassBottomBarExtraButton
- Configuration for the extra button in GlassBottomBar and GlassSearchableBottomBar.
- GlassBottomBarTab
- Configuration for a tab in GlassBottomBar.
- JellyClipper
- Clipper that matches the shape and physics of the jelly indicator.
Enums
- ExtraButtonPosition
- Where a GlassBottomBarExtraButton appears relative to the search pill in a GlassSearchableBottomBar.
- GlassTabPillAnchor
- Controls how the tab pill is anchored horizontally during the morph animation in GlassSearchableBottomBar.
- MaskingQuality
- A glass morphism bottom navigation bar following Apple's design patterns.