GlassExtraButtonPlacement enum
Where a GlassTabBarExtraButton appears in a non-searchable GlassBottomBar or GlassTabBar.bottom.
Defaults to GlassExtraButtonPlacement.right, matching the original bottom-bar layout.
Values
- left → const GlassExtraButtonPlacement
-
Place the button on the physical left side of the bar, before the tabs.
- right → const GlassExtraButtonPlacement
-
Place the button on the physical right side of the bar, after the tabs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GlassExtraButtonPlacement> - A constant List of the values in this enum, in order of their declaration.