SearchablePillLayout class
Immutable result of one SearchableBottomBarController.computeLayout call.
All values are in logical pixels and represent the target positions for the spring animations — not the current animated positions.
- Annotations
Constructors
Properties
- dismissReserve → double
-
Width reserved for the dismiss pill (0 when not shown).
final
- extraTargetW → double
-
Width reserved for the extra action button in the current state.
final
- floatY → double
-
Y offset that floats both pills above the keyboard when it is visible.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetSearchLeft → double
-
Target left edge of the search pill.
final
- targetSearchW → double
-
Target width of the search pill.
final
- targetTabW → double
-
Target width of the tab pill.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override