GlassTabBarExtraButton class

Configuration for the extra button in GlassTabBar.

The extra button is rendered as a GlassButton and typically used for primary actions like creating new content.

Constructors

GlassTabBarExtraButton({required Widget icon, required VoidCallback onTap, required String label, Color? iconColor, double size = 64, GlassExtraButtonPlacement placement = GlassExtraButtonPlacement.right, GlassExtraButtonPosition position = GlassExtraButtonPosition.beforeSearch, bool collapseOnSearchFocus = true, bool enabled = true})
Creates an extra button configuration.
const
GlassTabBarExtraButton.menu({required Widget icon, required List<Widget> menuItems, required String label, Color? iconColor, double size = 64, GlassExtraButtonPlacement placement = GlassExtraButtonPlacement.right, GlassExtraButtonPosition position = GlassExtraButtonPosition.beforeSearch, bool collapseOnSearchFocus = true, bool enabled = true, GlassMenuAlignment? menuAlignment, double menuWidth = 200})
Opens a GlassMenu pull-down when the extra button is tapped.
const

Properties

collapseOnSearchFocus → bool
Whether this button collapses (hides + frees layout space) when the search field is focused (i.e. the keyboard is visible).
final
enabled → bool
Whether the button is interactive.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
Icon widget displayed in the button.
final
iconColor → Color?
Color used for the button's icon.
final
isMenu → bool
Whether this button opens a menu rather than firing a tap callback.
no setter
label → String
Accessibility label for the button.
final
Controls where the menu expands relative to the trigger button.
final
When non-null, tapping this button opens a GlassMenu pull-down.
final
Width of the expanded menu panel in logical pixels.
final
onTap → VoidCallback
Callback when the button is tapped.
final
placement → GlassExtraButtonPlacement
Where this button is placed in GlassTabBar.bottom.
final
position → GlassExtraButtonPosition
Where this button is placed relative to the search pill in a searchable tab bar.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
Width and height of the button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited